@@ -41,6 +41,8 @@ __all__ = (
     "MetricDataQueryTypeDef",
     "MetricDataResultTypeDef",
     "MetricStatTypeDef",
+    "MetricStreamEntryTypeDef",
+    "MetricStreamFilterTypeDef",
     "MetricTypeDef",
     "PartialFailureTypeDef",
     "RangeTypeDef",
@@ -60,14 +62,17 @@ __all__ = (
     "GetInsightRuleReportOutputTypeDef",
     "GetMetricDataOutputTypeDef",
     "GetMetricStatisticsOutputTypeDef",
+    "GetMetricStreamOutputTypeDef",
     "GetMetricWidgetImageOutputTypeDef",
     "LabelOptionsTypeDef",
     "ListDashboardsOutputTypeDef",
+    "ListMetricStreamsOutputTypeDef",
     "ListMetricsOutputTypeDef",
     "ListTagsForResourceOutputTypeDef",
     "MetricDatumTypeDef",
     "PaginatorConfigTypeDef",
     "PutDashboardOutputTypeDef",
+    "PutMetricStreamOutputTypeDef",
     "WaiterConfigTypeDef",
 )
 
@@ -366,6 +371,22 @@ class MetricStatTypeDef(_RequiredMetricStatTypeDef, _OptionalMetricStatTypeDef):
     pass
 
 
+MetricStreamEntryTypeDef = TypedDict(
+    "MetricStreamEntryTypeDef",
+    {
+        "Arn": str,
+        "CreationDate": datetime,
+        "LastUpdateDate": datetime,
+        "Name": str,
+        "FirehoseArn": str,
+        "State": str,
+        "OutputFormat": Literal["json", "opentelemetry0.7"],
+    },
+    total=False,
+)
+
+MetricStreamFilterTypeDef = TypedDict("MetricStreamFilterTypeDef", {"Namespace": str}, total=False)
+
 MetricTypeDef = TypedDict(
     "MetricTypeDef",
     {"Namespace": str, "MetricName": str, "Dimensions": List["DimensionTypeDef"]},
@@ -514,6 +535,24 @@ GetMetricStatisticsOutputTypeDef = TypedDict(
     total=False,
 )
 
+GetMetricStreamOutputTypeDef = TypedDict(
+    "GetMetricStreamOutputTypeDef",
+    {
+        "Arn": str,
+        "Name": str,
+        "IncludeFilters": List["MetricStreamFilterTypeDef"],
+        "ExcludeFilters": List["MetricStreamFilterTypeDef"],
+        "FirehoseArn": str,
+        "RoleArn": str,
+        "State": str,
+        "CreationDate": datetime,
+        "LastUpdateDate": datetime,
+        "OutputFormat": Literal["json", "opentelemetry0.7"],
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
 GetMetricWidgetImageOutputTypeDef = TypedDict(
     "GetMetricWidgetImageOutputTypeDef",
     {"MetricWidgetImage": Union[bytes, IO[bytes]], "ResponseMetadata": "ResponseMetadata"},
@@ -532,6 +571,16 @@ ListDashboardsOutputTypeDef = TypedDict(
     total=False,
 )
 
+ListMetricStreamsOutputTypeDef = TypedDict(
+    "ListMetricStreamsOutputTypeDef",
+    {
+        "NextToken": str,
+        "Entries": List["MetricStreamEntryTypeDef"],
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
 ListMetricsOutputTypeDef = TypedDict(
     "ListMetricsOutputTypeDef",
     {"Metrics": List["MetricTypeDef"], "NextToken": str, "ResponseMetadata": "ResponseMetadata"},
@@ -606,6 +655,12 @@ PutDashboardOutputTypeDef = TypedDict(
     total=False,
 )
 
+PutMetricStreamOutputTypeDef = TypedDict(
+    "PutMetricStreamOutputTypeDef",
+    {"Arn": str, "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
 WaiterConfigTypeDef = TypedDict(
     "WaiterConfigTypeDef", {"Delay": int, "MaxAttempts": int}, total=False
 )
